<c-vars type="button" />
{% if url %}
<a href="{{ url }}" class="{{ class }}" style="display: inline-flex;" {{ attrs }}>
    {% else %}
    <button type="{{ type }}" class="{{ class }}" style="display: inline-flex;" {{ attrs }}>
        {% endif %}

        {% if trail %}
        {{ slot }}
        {% endif %}

        {{ label }}

        {% if lead %}
        {{ slot }}
        {% endif %}

        {% if url %}
</a>
{% else %}
</button>
{% endif %}